These create discrete color scales using the hues in the Sage branded colors list.
scale_colour_sage_d(..., level = "500", direction = 1, aesthetics = "colour")
scale_fill_sage_d(..., level = "500", direction = 1, aesthetics = "fill")Options passed to ggplot2::discrete_scale()
Color intensity. One of "200", "300", "400", "500", "600", "700", "800".
Sets the order of colors in the scale
Character string or vector of character strings listing the
name(s) of the aesthetic(s) that this scale works with. This can be useful, for
example, to apply colour settings to the colour and fill aesthetics at the
same time, via aesthetics = c("colour", "fill").